==> junit-quickcheck-generators-0.6-sources.jar: com/pholser/junit/quickcheck/generator/java/util/function/BiPredicateGenerator.java <==
/*
 The MIT License

 Copyright (c) 2010-2016 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package com.pholser.junit.quickcheck.generator.java.util.function;

import java.util.function.BiPredicate;

import com.pholser.junit.quickcheck.generator.ComponentizedGenerator;
import com.pholser.junit.quickcheck.generator.GenerationStatus;
import com.pholser.junit.quickcheck.generator.java.lang.BooleanGenerator;
import com.pholser.junit.quickcheck.random.SourceOfRandomness;

import static com.pholser.junit.quickcheck.generator.Lambdas.*;

/**
 * Produces values of type {@link BiPredicate}.
 *
 * @param <T> type of first parameter of produced predicate
 * @param <U> type of second parameter of produced predicate
 */
public class BiPredicateGenerator<T, U> extends ComponentizedGenerator<BiPredicate> {
    private final BooleanGenerator booleanGenerator = new BooleanGenerator();

    public BiPredicateGenerator() {
        super(BiPredicate.class);
    }

    @SuppressWarnings("unchecked")
    @Override public BiPredicate<T, U> generate(SourceOfRandomness random, GenerationStatus status) {
        return makeLambda(BiPredicate.class, booleanGenerator, status);
    }

    @Override public int numberOfNeededComponents() {
        return 2;
    }
}

==> junit-quickcheck-generators-0.9-sources.jar: com/pholser/junit/quickcheck/generator/java/util/function/BiPredicateGenerator.java <==
/*
 The MIT License

 Copyright (c) 2010-2018 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package com.pholser.junit.quickcheck.generator.java.util.function;

import java.util.function.BiPredicate;

import com.pholser.junit.quickcheck.generator.ComponentizedGenerator;
import com.pholser.junit.quickcheck.generator.GenerationStatus;
import com.pholser.junit.quickcheck.random.SourceOfRandomness;

import static com.pholser.junit.quickcheck.generator.Lambdas.*;

/**
 * Produces values of type {@link BiPredicate}.
 *
 * @param <T> type of first parameter of produced predicate
 * @param <U> type of second parameter of produced predicate
 */
public class BiPredicateGenerator<T, U> extends ComponentizedGenerator<BiPredicate> {
    public BiPredicateGenerator() {
        super(BiPredicate.class);
    }

    @SuppressWarnings("unchecked")
    @Override public BiPredicate<T, U> generate(SourceOfRandomness random, GenerationStatus status) {
        return makeLambda(BiPredicate.class, gen().type(boolean.class), status);
    }

    @Override public int numberOfNeededComponents() {
        return 2;
    }
}
